@@ -6,9 +6,9 @@ Type annotations for imagebuilder service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_imagebuilder.type_defs import AmiDistributionConfigurationTypeDef
+    from mypy_boto3_imagebuilder.type_defs import AdditionalInstanceConfigurationTypeDef
 
-    data: AmiDistributionConfigurationTypeDef = {...}
+    data: AdditionalInstanceConfigurationTypeDef = {...}
     ```
 """
 import sys
@@ -36,11 +36,14 @@ else:
 
 
 __all__ = (
+    "AdditionalInstanceConfigurationTypeDef",
     "AmiDistributionConfigurationTypeDef",
     "AmiTypeDef",
     "CancelImageCreationRequestRequestTypeDef",
     "CancelImageCreationResponseTypeDef",
     "ComponentConfigurationTypeDef",
+    "ComponentParameterDetailTypeDef",
+    "ComponentParameterTypeDef",
     "ComponentSummaryTypeDef",
     "ComponentTypeDef",
     "ComponentVersionTypeDef",
@@ -159,6 +162,7 @@ __all__ = (
     "ScheduleTypeDef",
     "StartImagePipelineExecutionRequestRequestTypeDef",
     "StartImagePipelineExecutionResponseTypeDef",
+    "SystemsManagerAgentTypeDef",
     "TagResourceRequestRequestTypeDef",
     "TargetContainerRepositoryTypeDef",
     "UntagResourceRequestRequestTypeDef",
@@ -170,6 +174,15 @@ __all__ = (
     "UpdateInfrastructureConfigurationResponseTypeDef",
 )
 
+AdditionalInstanceConfigurationTypeDef = TypedDict(
+    "AdditionalInstanceConfigurationTypeDef",
+    {
+        "systemsManagerAgent": "SystemsManagerAgentTypeDef",
+        "userDataOverride": str,
+    },
+    total=False,
+)
+
 AmiDistributionConfigurationTypeDef = TypedDict(
     "AmiDistributionConfigurationTypeDef",
     {
@@ -214,12 +227,57 @@ CancelImageCreationResponseTypeDef = TypedDict(
     },
 )
 
-ComponentConfigurationTypeDef = TypedDict(
-    "ComponentConfigurationTypeDef",
+_RequiredComponentConfigurationTypeDef = TypedDict(
+    "_RequiredComponentConfigurationTypeDef",
     {
         "componentArn": str,
     },
 )
+_OptionalComponentConfigurationTypeDef = TypedDict(
+    "_OptionalComponentConfigurationTypeDef",
+    {
+        "parameters": List["ComponentParameterTypeDef"],
+    },
+    total=False,
+)
+
+
+class ComponentConfigurationTypeDef(
+    _RequiredComponentConfigurationTypeDef, _OptionalComponentConfigurationTypeDef
+):
+    pass
+
+
+_RequiredComponentParameterDetailTypeDef = TypedDict(
+    "_RequiredComponentParameterDetailTypeDef",
+    {
+        "name": str,
+        "type": str,
+    },
+)
+_OptionalComponentParameterDetailTypeDef = TypedDict(
+    "_OptionalComponentParameterDetailTypeDef",
+    {
+        "defaultValue": List[str],
+        "description": str,
+    },
+    total=False,
+)
+
+
+class ComponentParameterDetailTypeDef(
+    _RequiredComponentParameterDetailTypeDef, _OptionalComponentParameterDetailTypeDef
+):
+    pass
+
+
+ComponentParameterTypeDef = TypedDict(
+    "ComponentParameterTypeDef",
+    {
+        "name": str,
+        "value": List[str],
+    },
+)
 
 ComponentSummaryTypeDef = TypedDict(
     "ComponentSummaryTypeDef",
@@ -250,6 +308,7 @@ ComponentTypeDef = TypedDict(
         "type": ComponentTypeType,
         "platform": PlatformType,
         "supportedOsVersions": List[str],
+        "parameters": List["ComponentParameterDetailTypeDef"],
         "owner": str,
         "data": str,
         "kmsKeyId": str,
@@ -527,6 +586,7 @@ _OptionalCreateImageRecipeRequestRequestTypeDef = TypedDict(
         "blockDeviceMappings": List["InstanceBlockDeviceMappingTypeDef"],
         "tags": Dict[str, str],
         "workingDirectory": str,
+        "additionalInstanceConfiguration": "AdditionalInstanceConfigurationTypeDef",
     },
     total=False,
 )
@@ -1065,6 +1125,7 @@ ImageRecipeTypeDef = TypedDict(
         "dateCreated": str,
         "tags": Dict[str, str],
         "workingDirectory": str,
+        "additionalInstanceConfiguration": "AdditionalInstanceConfigurationTypeDef",
     },
     total=False,
 )
@@ -1703,6 +1764,14 @@ StartImagePipelineExecutionResponseTypeDef = TypedDict(
     },
 )
 
+SystemsManagerAgentTypeDef = TypedDict(
+    "SystemsManagerAgentTypeDef",
+    {
+        "uninstallAfterBuild": bool,
+    },
+    total=False,
+)
+
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
